This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[debug] Remove deprecated DW_FORM_sig8 define


Hi,

While reading through the unit type support I noticed some parts were
still using the old DW_FORM_sig8 while others used the actual
DW_FORM_ref_sig8 as used in the dwarf spec. I missed some things in a
first scan because of this, so I thought I just clean it up.

2010-03-24  Mark Wielaard  <mjw@redhat.com>

    * dwarf2.h (dwarf_form): Remove deprecated DW_FORM_sig8 define.

2011-03-24  Mark Wielaard  <mjw@redhat.com>

    * dwarf2out.c (size_of_die): Modify comment to say DW_FORM_ref_sig8.
    (value_format): Use DW_FORM_ref_sig8, not DW_FORM_sig8.

binutils already only uses the new definition.
I have a similar cleanup patch for gdb.

OK, to commit?

Thanks,

Mark
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 9dec3e4..41d55bf 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,8 @@
+2011-03-24  Mark Wielaard  <mjw@redhat.com>
+
+	* dwarf2out.c (size_of_die): Modify comment to say DW_FORM_ref_sig8.
+	(value_format): Use DW_FORM_ref_sig8, not DW_FORM_sig8.
+
 2011-03-24  Richard Guenther  <rguenther@suse.de>
 
 	PR tree-optimization/46562
diff --git a/include/ChangeLog b/include/ChangeLog
index a0585b0..4a09ab6 100644
--- a/include/ChangeLog
+++ b/include/ChangeLog
@@ -1,3 +1,7 @@
+2010-03-24  Mark Wielaard  <mjw@redhat.com>
+
+	* dwarf2.h (dwarf_form): Remove deprecated DW_FORM_sig8 define.
+
 2010-03-23  Rafael Ãvila de EspÃndola <respindola@mozilla.com>
 
 	* plugin-api.h (ld_plugin_get_view): New.
diff --git a/include/dwarf2.h b/include/dwarf2.h
index 46f2291..ef0fa5f 100644
--- a/include/dwarf2.h
+++ b/include/dwarf2.h
@@ -189,7 +189,6 @@ enum dwarf_form
     DW_FORM_exprloc = 0x18,
     DW_FORM_flag_present = 0x19,
     DW_FORM_ref_sig8 = 0x20
-#define DW_FORM_sig8  DW_FORM_ref_sig8  /* Note: The use of DW_FORM_sig8 is deprecated.  */
   };
 
 /* Attribute names and codes.  */

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
diff --git a/gcc/dwarf2out.c b/gcc/dwarf2out.c
index aa6f6b6..bc05982 100644
--- a/gcc/dwarf2out.c
+++ b/gcc/dwarf2out.c
@@ -10729,7 +10729,7 @@ size_of_die (dw_die_ref die)
 	case dw_val_class_die_ref:
 	  if (AT_ref_external (a))
 	    {
 	      /* In DWARF4, we use DW_FORM_sig8; for earlier versions
 		 we use DW_FORM_ref_addr.  In DWARF2, DW_FORM_ref_addr
 		 is sized by target address length, whereas in DWARF3
 		 it's always sized as an offset.  */
@@ -11005,7 +11005,7 @@ value_format (dw_attr_ref a)
       return DW_FORM_flag;
     case dw_val_class_die_ref:
       if (AT_ref_external (a))
-	return dwarf_version >= 4 ? DW_FORM_sig8 : DW_FORM_ref_addr;
+	return dwarf_version >= 4 ? DW_FORM_ref_sig8 : DW_FORM_ref_addr;
       else
 	return DW_FORM_ref;
     case dw_val_class_fde_ref:
@@ -10729,7 +10729,7 @@ size_of_die (dw_die_ref die)
 	  if (AT_ref_external (a))
 	    {
-	      /* In DWARF4, we use DW_FORM_sig8; for earlier versions
+	      /* In DWARF4, we use DW_FORM_ref_sig8; for earlier versions
 		 we use DW_FORM_ref_addr.  In DWARF2, DW_FORM_ref_addr
 		 is sized by target address length, whereas in DWARF3